@@ -238,7 +238,7 @@ clearlooks_inverted_draw_progressbar_fill (cairo_t *cr,
 	cairo_pattern_destroy (pattern);
 
 	/* Draw the Strokes */
-	while (tile_pos <= width+x_step)
+	while (stroke_width > 0 && tile_pos <= width+x_step)
 	{
 		cairo_move_to (cr, stroke_width/2-x_step, 0);
 		cairo_line_to (cr, stroke_width-x_step,   0);
@@ -768,34 +768,34 @@ clearlooks_inverted_draw_scrollbar_stepper (cairo_t *cr,
 
 	if (scrollbar->horizontal)
 	{
-		if (stepper->stepper == CL_STEPPER_A)
+		if (stepper->stepper == CL_STEPPER_START)
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
-		else if (stepper->stepper == CL_STEPPER_D)
+		else if (stepper->stepper == CL_STEPPER_END)
 			corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
 
-		if (stepper->stepper == CL_STEPPER_B)
+		if (stepper->stepper == CL_STEPPER_START_INNER)
 		{
 			x -= 1;
 			width += 1;
 		}
-		else if (stepper->stepper == CL_STEPPER_C)
+		else if (stepper->stepper == CL_STEPPER_END_INNER)
 		{
 			width += 1;
 		}
 	}
 	else
 	{
-		if (stepper->stepper == CL_STEPPER_A)
+		if (stepper->stepper == CL_STEPPER_START)
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT;
-		else if (stepper->stepper == CL_STEPPER_D)
+		else if (stepper->stepper == CL_STEPPER_END)
 			corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_BOTTOMRIGHT;
 
-		if (stepper->stepper == CL_STEPPER_B)
+		if (stepper->stepper == CL_STEPPER_START_INNER)
 		{
 			y -= 1;
 			height += 1;
 		}
-		else if (stepper->stepper == CL_STEPPER_C)
+		else if (stepper->stepper == CL_STEPPER_END_INNER)
 		{
 			height += 1;
 		}
