@@ -1,28 +1,32 @@
-/* Clearlooks theme engine
- * Copyright (C) 2005 Richard Stellingwerff
- * Copyright (C) 2007 Benjamin Berg
- * Copyright (C) 2007 Andrea Cimitan
+/* Clearlooks - a cairo based GTK+ engine
+ * Copyright (C) 2005 Richard Stellingwerff <remenic@gmail.com>
+ * Copyright (C) 2007 Benjamin Berg <benjamin@sipsolutions.net>
+ * Copyright (C) 2007-2008 Andrea Cimitan <andrea.cimitan@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Project contact: <gnome-themes-list@gnome.org>
  *
- * Written by Owen Taylor <otaylor@redhat.com>
- * and by Alexander Larsson <alexl@redhat.com>
+ *
+ * Originally written by Owen Taylor <otaylor@redhat.com>
+ *                and by Alexander Larsson <alexl@redhat.com>
  * Modified by Richard Stellingwerff <remenic@gmail.com>
  * Modified by Kulyk Nazar <schamane@myeburg.net>
+ *
  */
+ 
 
 #include <string.h>
 #include <widget-information.h>
@@ -31,7 +35,7 @@
 
 #include "animation.h"
 
-#ifdef HAVE_ANIMATION
+#ifdef HAVE_WORKING_ANIMATION
 static void      clearlooks_rc_style_finalize     (GObject                *object);
 #endif
 static GtkStyle *clearlooks_rc_style_create_style (GtkRcStyle             *rc_style);
@@ -59,11 +63,13 @@ enum
 	TOKEN_RADIUS,
 	TOKEN_HINT,
 	TOKEN_DISABLE_FOCUS,
+	TOKEN_ACCEL_LABEL_SHADE,
 
 	TOKEN_CLASSIC,
 	TOKEN_GLOSSY,
 	TOKEN_INVERTED,
 	TOKEN_GUMMY,
+	TOKEN_GNOME3,
 
 	TOKEN_TRUE,
 	TOKEN_FALSE,
@@ -88,11 +94,13 @@ static gchar* clearlooks_rc_symbols =
 	"radius\0"
 	"hint\0"
 	"disable_focus\0"
+	"accel_label_shade\0"
 
 	"CLASSIC\0"
 	"GLOSSY\0"
 	"INVERTED\0"
 	"GUMMY\0"
+	"GNOME3\0"
 
 	"TRUE\0"
 	"FALSE\0";
@@ -121,9 +129,10 @@ clearlooks_rc_style_init (ClearlooksRcStyle *clearlooks_rc)
 	clearlooks_rc->radius = 3.0;
 	clearlooks_rc->hint = 0;
 	clearlooks_rc->disable_focus = FALSE;
+	clearlooks_rc->accel_label_shade = 1.0;
 }
 
-#ifdef HAVE_ANIMATION
+#ifdef HAVE_WORKING_ANIMATION
 static void
 clearlooks_rc_style_finalize (GObject *object)
 {
@@ -140,7 +149,7 @@ static void
 clearlooks_rc_style_class_init (ClearlooksRcStyleClass *klass)
 {
 	GtkRcStyleClass *rc_style_class = GTK_RC_STYLE_CLASS (klass);
-#ifdef HAVE_ANIMATION
+#ifdef HAVE_WORKING_ANIMATION
 	GObjectClass    *g_object_class = G_OBJECT_CLASS (klass);
 #endif
 
@@ -148,7 +157,7 @@ clearlooks_rc_style_class_init (ClearlooksRcStyleClass *klass)
 	rc_style_class->create_style = clearlooks_rc_style_create_style;
 	rc_style_class->merge = clearlooks_rc_style_merge;
 
-#ifdef HAVE_ANIMATION
+#ifdef HAVE_WORKING_ANIMATION
 	g_object_class->finalize = clearlooks_rc_style_finalize;
 #endif
 }
@@ -252,7 +261,7 @@ clearlooks_gtk2_rc_parse_style (GtkSettings      *settings,
 {
 	guint token;
 
-	g_assert (CL_NUM_STYLES == CL_STYLE_GUMMY + 1); /* so that people don't forget ;-) */
+	g_assert (CL_NUM_STYLES == CL_STYLE_GNOME3 + 1); /* so that people don't forget ;-) */
 
 	/* Skip 'style' */
 	token = g_scanner_get_next_token (scanner);
@@ -277,6 +286,9 @@ clearlooks_gtk2_rc_parse_style (GtkSettings      *settings,
 		case TOKEN_GUMMY:
 		   *style = CL_STYLE_GUMMY;
 		   break;
+		case TOKEN_GNOME3:
+		   *style = CL_STYLE_GNOME3;
+		   break;
 		default:
 		   return TOKEN_CLASSIC;
 	}
@@ -402,6 +414,10 @@ clearlooks_rc_style_parse (GtkRcStyle *rc_style,
 				token = clearlooks_gtk2_rc_parse_boolean (settings, scanner, &clearlooks_style->disable_focus);
 				clearlooks_style->flags |= CL_FLAG_DISABLE_FOCUS;
 				break;
+			case TOKEN_ACCEL_LABEL_SHADE:
+				token = clearlooks_gtk2_rc_parse_double (settings, scanner, &clearlooks_style->accel_label_shade);
+				clearlooks_style->flags |= CL_FLAG_ACCEL_LABEL_SHADE;
+				break;
 
 			/* stuff to ignore */
 			case TOKEN_SUNKENMENU:
@@ -477,6 +493,8 @@ clearlooks_rc_style_merge (GtkRcStyle *dest,
 		dest_w->hint = src_w->hint;
 	if (flags & CL_FLAG_DISABLE_FOCUS)
 		dest_w->disable_focus = src_w->disable_focus;
+	if (flags & CL_FLAG_ACCEL_LABEL_SHADE)
+		dest_w->accel_label_shade = src_w->accel_label_shade;
 
 	dest_w->flags |= src_w->flags;
 }
