@@ -39,10 +39,6 @@ GE_INTERNAL void              clearlooks_treeview_get_header_index (GtkTreeView
                                                  gint         *columns,
                                                  gboolean     *resizable);
 
-GE_INTERNAL void              clearlooks_clist_get_header_index    (GtkCList     *clist,
-                                                 GtkWidget    *button,
-                                                 gint         *column_index,
-                                                 gint         *columns);
 #ifdef DEVELOPMENT
 #warning clearlooks_get_parent_bg is a bad hack - find out why its needed, and figure out a better way.
 #endif
