@@ -1,22 +1,32 @@
-/**************************************************************************
-* GTK Industrial Theme
-* Designed by Tigert and Jimmac
-* Implemented by Christopher James Lahey
-*
-* Based on GTK Bluecurve Theme
-* Designed by Garrett LeSage
-* Implemented by Alexander Larsson
-*
-* Parts of the code based on Metal theme, Copyright:
-* Randy Gordon, randy@integrand.com
-* Owen Taylor <otaylor@redhat.com>
-*
-* Ported to cairo by:
-* Benjamin Berg <benjamin@sipsolutions.net>
-*
-* License: GPL (Gnu Public License)
-*
-**************************************************************************/
+/* Industrial - a cairo based GTK+ engine
+ * Copyright (C) 2001 Red Hat, Inc.
+ * Copyright (C) 2002 Ximian, Inc.
+ * Copyright (C) 2006-2007 Benjamin Berg <benjamin@sipsolutions.net>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * Project contact: <gnome-themes-list@gnome.org>
+ *
+ *
+ * Written by Owen Taylor <otaylor@redhat.com>
+ * modified by Alexander Larsson <alexl@redhat.com>
+ * modified by Christopher James Lahey <clahey@ximian.com>
+ * modified by Benjamin Berg <benjamin@sipsolutions.net>
+ *
+ */
+
 
 #include "industrial_style.h"
 #include "industrial_rc_style.h"
@@ -516,17 +526,18 @@ draw_slider (GtkStyle      *style,
 	
 	/* This makes the slider overlay the stepper buttons at the sides. XXX */
 	if (widget && GE_IS_SCROLLBAR (widget)) {
-		GtkAdjustment *adjustment = GTK_RANGE (widget)->adjustment;
+		GtkAdjustment *adjustment = gtk_range_get_adjustment (GTK_RANGE (widget));
 
 		/* If all of these values are 0, don't do anything.  This fixes mozilla/galeon scrollbars. */
-		if (adjustment->value ||
-		    adjustment->lower ||
-		    adjustment->upper ||
-		    adjustment->step_increment ||
-		    adjustment->page_increment ||
-		    adjustment->page_size) {
-			if ((adjustment->value <= adjustment->lower) &&
-			    (GTK_RANGE (widget)->has_stepper_a || GTK_RANGE (widget)->has_stepper_b)) {
+		if (gtk_adjustment_get_value (adjustment) ||
+		    gtk_adjustment_get_lower (adjustment) ||
+		    gtk_adjustment_get_upper (adjustment) ||
+		    gtk_adjustment_get_step_increment (adjustment) ||
+		    gtk_adjustment_get_page_increment (adjustment) ||
+		    gtk_adjustment_get_page_size (adjustment)) {
+			/* XXX: Need a way to check whether there are any steppers at the top/bottom. */
+			if ((gtk_adjustment_get_value (adjustment) <= gtk_adjustment_get_lower (adjustment)) /*&&
+			    (GTK_RANGE (widget)->has_stepper_a || GTK_RANGE (widget)->has_stepper_b)*/) {
 				if (orientation == GTK_ORIENTATION_VERTICAL) {
 					if (!gtk_range_get_inverted (GTK_RANGE (widget)))
 						y--;
@@ -537,8 +548,8 @@ draw_slider (GtkStyle      *style,
 					width++;
 				}
 			}
-			if ((adjustment->value >= adjustment->upper - adjustment->page_size) &&
-			    (GTK_RANGE (widget)->has_stepper_a || GTK_RANGE (widget)->has_stepper_b)) {
+			if ((gtk_adjustment_get_value (adjustment) >= gtk_adjustment_get_upper (adjustment) - gtk_adjustment_get_page_size (adjustment)) /*&&
+			    (GTK_RANGE (widget)->has_stepper_a || GTK_RANGE (widget)->has_stepper_b)*/) {
 				if (orientation == GTK_ORIENTATION_VERTICAL) {
 					if (gtk_range_get_inverted (GTK_RANGE (widget)))
 						y--;
@@ -1722,4 +1733,7 @@ industrial_style_class_init (IndustrialStyleClass * klass)
 	style_class->render_icon = render_icon;
 }
 
-
+static void
+industrial_style_class_finalize (IndustrialStyleClass *klass)
+{
+}
