@@ -284,7 +284,7 @@ mist_style_draw_shadow(GtkStyle *style,
 		shadow_type = GTK_SHADOW_ETCHED_IN;
 	}
 	
-	if (CHECK_DETAIL(detail, "frame") && widget && widget->parent && GE_IS_STATUSBAR (widget->parent)) {
+	if (CHECK_DETAIL(detail, "frame") && widget && gtk_widget_get_parent (widget) && GE_IS_STATUSBAR (gtk_widget_get_parent (widget))) {
 		ge_cairo_set_color(cr, &mist_style->color_cube.dark[GTK_STATE_NORMAL]);	
 
 		cairo_move_to (cr, x + 0.5, y + 0.5);
@@ -603,10 +603,11 @@ mist_style_draw_box(GtkStyle *style,
 		/* Make sure stepper and slider outlines "overlap" - taken from
 		 * bluecurve */
 		if (CHECK_DETAIL(detail, "slider") && widget && GE_IS_RANGE (widget)) {
-			GtkAdjustment *adj = GTK_RANGE (widget)->adjustment;
-			if (adj->value <= adj->lower &&
+			GtkAdjustment *adj = gtk_range_get_adjustment (GTK_RANGE (widget));
+			/* XXX: Need a way to get figure out where steppers are for this hack to work properly. */
+			if (gtk_adjustment_get_value (adj) <= gtk_adjustment_get_lower (adj) /*&&
 			    (GTK_RANGE (widget)->has_stepper_a ||
-			     GTK_RANGE (widget)->has_stepper_b)) {
+			     GTK_RANGE (widget)->has_stepper_b)*/) {
 				if (GE_IS_VSCROLLBAR (widget)) {
 					height += 1;
 					if (!gtk_range_get_inverted (GTK_RANGE (widget)))
@@ -618,9 +619,9 @@ mist_style_draw_box(GtkStyle *style,
 				}
 			}
 			
-			if (adj->value >= adj->upper - adj->page_size &&
+			if (gtk_adjustment_get_value (adj) >= gtk_adjustment_get_upper (adj) - gtk_adjustment_get_page_size (adj) /*&&
 			    (GTK_RANGE (widget)->has_stepper_c ||
-			     GTK_RANGE (widget)->has_stepper_d)) {
+			     GTK_RANGE (widget)->has_stepper_d)*/) {
 				if (GE_IS_VSCROLLBAR (widget)) {
 					height += 1;
 					if (gtk_range_get_inverted (GTK_RANGE (widget)))
@@ -1161,42 +1162,6 @@ mist_style_draw_resize_grip(GtkStyle *style,
 	cairo_destroy(cr);
 }
 
-#ifndef GTK_DISABLE_DEPRECATED
-#ifndef GDK_DISABLE_DEPRECATED
-#define DISABLE_CUSTOM_STRING_DRAWING
-#warning Disabling custom string drawing so that no deprecated API is used.
-#endif /* GDK_DISABLE_DEPRECATED */
-#endif /* GTK_DISABLE_DEPRECATED */
-
-#ifndef DISABLE_CUSTOM_STRING_DRAWING
-static void
-mist_style_draw_string (GtkStyle      *style,
-	     GdkWindow     *window,
-	     GtkStateType   state_type,
-	     GdkRectangle  *area,
-	     GtkWidget     *widget,
-	     const char    *detail,
-	     int            x,
-	     int            y,
-	     const char    *string)
-{
-	CHECK_ARGS
-	
-	if (area) {
-		gdk_gc_set_clip_rectangle (style->fg_gc[state_type], area);
-	}	
-	
-	gdk_draw_string (window,
-			 gtk_style_get_font (style),
-			 style->fg_gc[state_type], x, y, string);
-	
-	if (area) {
-		gdk_gc_set_clip_rectangle (style->fg_gc[state_type], NULL);
-	}
-}
-#endif /* DISABLE_CUSTOM_STRING_DRAWING */
-
-
 static void
 mist_style_draw_layout (GtkStyle        *style,
 	     GdkWindow       *window,
@@ -1418,9 +1383,6 @@ mist_style_class_init (MistStyleClass *klass)
 	style_class->draw_extension = mist_style_draw_extension;
 	style_class->draw_handle = mist_style_draw_handle;
 	style_class->draw_resize_grip = mist_style_draw_resize_grip;
-#ifndef DISABLE_CUSTOM_STRING_DRAWING
-	style_class->draw_string = mist_style_draw_string;
-#endif
 	style_class->draw_layout = mist_style_draw_layout;
 	style_class->render_icon = mist_style_render_icon;
 	style_class->draw_focus = mist_style_draw_focus;
